@@ -1,5 +1,5 @@
 #!/bin/bash
-#  Copyright (C) 2000-2008, Parallels, Inc. All rights reserved.
+#  Copyright (C) 2000-2009, Parallels, Inc. All rights reserved.
 #
 #  This program is free software; you can redistribute it and/or modify
 #  it under the terms of the GNU General Public License as published by
@@ -26,36 +26,57 @@ IFCFG=${IFCFG_DIR}${VENET_DEV_CFG}
 # Function to delete IP address for RedHat like systems
 function del_ip()
 {
-	local ip
+	local ipm
 	local filetodel
 	local file
 	local aliasid
+	local addr
 
 	[ -d ${IFCFG_DIR} ] || return 0
 	cd ${IFCFG_DIR} || return 0
 	if [ "x${IPDELALL}" = "xyes" ]; then
 		ifdown ${VENET_DEV} >/dev/null 2>&1
 		rm -f ${VENET_DEV_CFG} ${VENET_DEV_CFG}:* 2>/dev/null
-		del_param ${IFCFG} IPV6ADDR_SECONDARIES ""
-		return 0;
+		return 0
 	fi
-	for ip in ${IP_ADDR}; do
+	for ipm in ${IP_ADDR}; do
+		ip_conv $ipm
 		# IPV6 processing
-		if [ "${ip#*:}" != "${ip}" ]; then
-			del_param ${IFCFG} IPV6ADDR_SECONDARIES "${ip}\\/128"
-			ifconfig ${VENET_DEV} del ${ip}/128
+		if [ -n "$_IPV6ADDR" ]; then
+			del_param ${IFCFG} IPV6ADDR_SECONDARIES "${_IP}\\/${_MASK}"
+			if have_ifconfig; then
+				ifconfig ${VENET_DEV} del ${_IP}/${_MASK}
+			else
+				ip a d ${_IP}/${_MASK} dev ${VENET_DEV}
+			fi
 			continue
 		fi
 		# find and delete a file with this alias
-		filetodel=`grep -l "IPADDR=${ip}$" \
+		filetodel=`grep -l "IPADDR=${_IP}$" \
 			${VENET_DEV_CFG}:* 2>/dev/null`
 		for file in ${filetodel}; do
 			rm -f "${file}"
 			aliasid=`echo ${file} | sed s/.*://g`
 			if [ -n "${aliasid}" ]; then
-				ifconfig ${VENET_DEV}:${aliasid} down >/dev/null 2>&1
+				if have_ifconfig; then
+					ifconfig ${VENET_DEV}:${aliasid} down >/dev/null 2>&1
+				else
+					ip a d ${_IP}/${_MASK} dev ${VENET_DEV} >/dev/null 2>&1
+				fi
 			fi
 		done
+		# Even if file not found, try to delete by address
+		if have_ifconfig; then
+			for aliasid in $(ifconfig | grep -B1 "\\<inet addr:${_IP}\\>" |
+					awk "/^${VENET_DEV}:/ {print \$1}"); do
+				ifconfig ${aliasid} down >/dev/null 2>&1
+			done
+		else
+			for addr in $(ip a l dev ${VENET_DEV} |
+					grep -Fw ${_IP} | awk '{print $2}'); do
+				ip a d $addr dev ${VENET_DEV} >/dev/null 2>&1
+			done
+		fi
 	done
 }
 
