@@ -1673,7 +1673,7 @@ static int get_ves_cpu()
 		}
 		if (id && !veid) {
 			rate = rint((double)rate * 100 / 1024);
-			weight = MAXCPUUNITS / weight;
+			weight = rint((double)MAXCPUUNITS / weight);
 			update_cpu(id, rate, weight);
 		}
 	}
@@ -1824,7 +1824,10 @@ static int collect()
 		return ret;
 	/* No CT found, exit with error */
 	if (!n_veinfo) {
-		fprintf(stderr, "Container(s) not found\n");
+		if (fmt_json)
+			printf("[]\n");
+		else
+			fprintf(stderr, "Container(s) not found\n");
 		return 1;
 	}
 	if (check_param(RES_CPUSTAT))
